@@ -1,3 +1,5 @@
+/*	$NetBSD: file.c,v 1.5 1998/02/07 00:03:22 cgd Exp $	*/
+
 /*
  * Copyright (c) 1995-96 Mats O Jansson.  All rights reserved.
  *
@@ -27,19 +29,21 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#ifndef LINT
-static char rcsid[] = "$Id: file.c,v 1.4 1996/08/16 22:39:22 moj Exp $";
+#include <sys/cdefs.h>
+#ifndef lint
+static char rcsid[]="$NetBSD: file.c,v 1.5 1998/02/07 00:03:22 cgd Exp $";
 #endif
 
 #include "os.h"
-#include "common/common.h"
-#include "common/mopdef.h"
+#include "common.h"
+#include "file.h"
+#include "mopdef.h"
 
 #ifndef NOAOUT
 #if defined(__NetBSD__) || defined(__OpenBSD__)
 #include <sys/exec_aout.h>
 #endif
-#if defined(__bsdi__)
+#if defined(__bsdi__) 
 #define NOAOUT
 #endif
 #if defined(__FreeBSD__)
@@ -48,13 +52,22 @@ static char rcsid[] = "$Id: file.c,v 1.4 1996/08/16 22:39:22 moj Exp $";
 #if !defined(MID_VAX)
 #define MID_VAX 140
 #endif
+#if defined(__linux__)
+#define NOAOUT
+#include <a.out.h>
+#define MID_I386 100
+#define MID_SPARC 3
 #endif
+#endif
+
+int	getCLBYTES __P((int));
+int	getMID __P((int, int));
 
 void
 mopFilePutLX(buf, index, value, cnt)
-	u_char	*buf;
-	int	index, cnt;
-	u_long	value;
+	u_char	       *buf;
+	int		index, cnt;
+	u_int32_t	value;
 {
 	int i;
 	for (i = 0; i < cnt; i++) {
@@ -65,9 +78,9 @@ mopFilePutLX(buf, index, value, cnt)
 
 void
 mopFilePutBX(buf, index, value, cnt)
-	u_char	*buf;
-	int	index, cnt;
-	u_long	value;
+	u_char	       *buf;
+	int		index, cnt;
+	u_int32_t	value;
 {
 	int i;
 	for (i = 0; i < cnt; i++) {
@@ -76,12 +89,12 @@ mopFilePutBX(buf, index, value, cnt)
 	}
 }
 
-u_long
+u_int32_t
 mopFileGetLX(buf, index, cnt)
 	u_char	*buf;
 	int	index, cnt;
 {
-	u_long ret = 0;
+	u_int32_t ret = 0;
 	int i;
 
 	for (i = 0; i < cnt; i++) {
@@ -91,12 +104,12 @@ mopFileGetLX(buf, index, cnt)
 	return(ret);
 }
 
-u_long
+u_int32_t
 mopFileGetBX(buf, index, cnt)
 	u_char	*buf;
 	int	index, cnt;
 {
-	u_long ret = 0;
+	u_int32_t ret = 0;
 	int i;
 
 	for (i = 0; i < cnt; i++) {
@@ -155,12 +168,12 @@ CheckMopFile(fd)
 
 int
 GetMopFileInfo(fd, load, xfr)
-	int	fd;
-	u_long	*load, *xfr;
+	int		fd;
+	u_int32_t      *load, *xfr;
 {
-	u_char	header[512];
-	short	image_type;
-	u_long	load_addr, xfr_addr, isd, iha, hbcnt, isize;
+	u_char		header[512];
+	short		image_type;
+	u_int32_t	load_addr, xfr_addr, isd, iha, hbcnt, isize;
 
 	if (read(fd, header, 512) != 512)
 		return(-1);
@@ -184,43 +197,33 @@ GetMopFileInfo(fd, load, xfr)
 				    header[iha+IHA_L_TFRADR1+2]*0x10000 +
 				    header[iha+IHA_L_TFRADR1+1]*0x100 +
 				    header[iha+IHA_L_TFRADR1]) & 0x7fffffff;
-#ifdef INFO
 			printf("Native Image (VAX)\n");
 			printf("Header Block Count: %d\n",hbcnt);
 			printf("Image Size:         %08x\n",isize);
 			printf("Load Address:       %08x\n",load_addr);
 			printf("Transfer Address:   %08x\n",xfr_addr);
-#endif
 			break;
 		case IHD_C_RSX:			/* RSX image produced by TKB */
 			hbcnt = header[L_BBLK+1]*256 + header[L_BBLK];
 			isize = (header[L_BLDZ+1]*256 + header[L_BLDZ]) * 64;
 			load_addr = header[L_BSA+1]*256 + header[L_BSA];
 			xfr_addr  = header[L_BXFR+1]*256 + header[L_BXFR];
-#ifdef INFO
 			printf("RSX Image\n");
 			printf("Header Block Count: %d\n",hbcnt);
 			printf("Image Size:         %08x\n",isize);
 			printf("Load Address:       %08x\n",load_addr);
 			printf("Transfer Address:   %08x\n",xfr_addr);
-#endif
 			break;
 		case IHD_C_BPA:			/* BASIC plus analog         */
-#ifdef INFO
 			printf("BASIC-Plus Image, not supported\n");
-#endif
 			return(-1);
 			break;
 		case IHD_C_ALIAS:		/* Alias		     */
-#ifdef INFO
 			printf("Alias, not supported\n");
-#endif
 			return(-1);
 			break;
 		case IHD_C_CLI:			/* Image is CLI		     */
-#ifdef INFO
 			printf("CLI, not supported\n");
-#endif
 			return(-1);
 			break;
 		case IHD_C_PMAX:		/* PMAX system image	     */
@@ -237,13 +240,11 @@ GetMopFileInfo(fd, load, xfr)
 				    header[iha+IHA_L_TFRADR1+2]*0x10000 +
 				    header[iha+IHA_L_TFRADR1+1]*0x100 +
 				    header[iha+IHA_L_TFRADR1]);
-#ifdef INFO
 			printf("PMAX Image \n");
 			printf("Header Block Count: %d\n",hbcnt);
 			printf("Image Size:         %08x\n",isize);
 			printf("Load Address:       %08x\n",load_addr);
 			printf("Transfer Address:   %08x\n",xfr_addr);
-#endif
 			break;
 		case IHD_C_ALPHA:		/* ALPHA system image	     */
 			isd = (header[EIHD_L_ISDOFF+3]*0x1000000 +
@@ -260,18 +261,14 @@ GetMopFileInfo(fd, load, xfr)
 				 header[isd+EISD_L_SECSIZE]);
 			load_addr = 0;
 			xfr_addr = 0;
-#ifdef INFO
 			printf("Alpha Image \n");
 			printf("Header Block Count: %d\n",hbcnt);
 			printf("Image Size:         %08x\n",isize);
 			printf("Load Address:       %08x\n",load_addr);
 			printf("Transfer Address:   %08x\n",xfr_addr);
-#endif
 			break;
 		default:
-#ifdef INFO
 			printf("Unknown Image (%d)\n",image_type);
-#endif
 			return(-1);
 	}
 
@@ -314,9 +311,6 @@ getMID(old_mid,new_mid)
 		mid = MID_NS32532;
 		break;
 #endif
-/*###323 [cc] for each function it appears in.)%%%*/
-/*###323 [cc] (Each undeclared identifier is reported only once%%%*/
-/*###323 [cc] `MID_SPARC' undeclared (first use this function)%%%*/
 	case MID_SPARC:
 		mid = MID_SPARC;
 		break;
@@ -346,7 +340,7 @@ getMID(old_mid,new_mid)
 		break;
 #endif
 	default:
-/*###352 [cc] syntax error before `}'%%%*/
+		break;
 	}
 
 	return(mid);
@@ -364,14 +358,15 @@ getCLBYTES(mid)
 		clbytes = 1024;
 		break;
 #endif
+#ifdef MID_I386
 	case MID_I386:
+#endif
 #ifdef MID_M68K4K
 	case MID_M68K4K:
 #endif
 #ifdef MID_NS32532
 	case MID_NS32532:
 #endif
-	case MID_SPARC:				/* It might be 8192 */
 #ifdef MID_PMAX
 	case MID_PMAX:
 #endif
@@ -381,15 +376,21 @@ getCLBYTES(mid)
 #ifdef MID_ARM6
 	case MID_ARM6:
 #endif
+#if defined(MID_I386) || defined(MID_M68K4K) || defined(MID_NS32532) || \
+    defined(MID_PMAX) || defined(MID_MIPS) || defined(MID_ARM6)
 		clbytes = 4096;
 		break;
+#endif
 #ifdef MID_M68K
 	case MID_M68K:
 #endif
 #ifdef MID_ALPHA
 	case MID_ALPHA:
 #endif
-#if defined(MID_M68K) || defined(MID_ALPHA)
+#ifdef MID_SPARC
+	case MID_SPARC:
+#endif
+#if defined(MID_M68K) || defined(MID_ALPHA) || defined(MID_SPARC)
 		clbytes = 8192;
 		break;
 #endif
@@ -401,7 +402,6 @@ getCLBYTES(mid)
 }
 #endif
 
-/*###406 [cc] syntax error before `int'%%%*/
 int
 CheckAOutFile(fd)
 	int	fd;
@@ -412,7 +412,6 @@ CheckAOutFile(fd)
 	struct exec ex, ex_swap;
 	int	mid = -1;
 
-/*###416 [cc] `fd' undeclared (first use this function)%%%*/
 	if (read(fd, (char *)&ex, sizeof(ex)) != sizeof(ex))
 		return(-1);
 
@@ -437,20 +436,20 @@ CheckAOutFile(fd)
 #endif NOAOUT
 }
 
-/*###440 [cc] syntax error before `int'%%%*/
 int
 GetAOutFileInfo(fd, load, xfr, a_text, a_text_fill,
 		a_data, a_data_fill, a_bss, a_bss_fill, aout)
-	int	fd, *aout;
-	u_long	*load, *xfr, *a_text, *a_text_fill;
-	u_long	*a_data, *a_data_fill, *a_bss, *a_bss_fill;
+	int		 fd;
+	u_int32_t	*load, *xfr, *a_text, *a_text_fill;
+	u_int32_t	*a_data, *a_data_fill, *a_bss, *a_bss_fill;
+	int		 *aout;
 {
 #ifdef NOAOUT
 	return(-1);
 #else
 	struct exec ex, ex_swap;
-	int	mid = -1;
-	u_long	magic, clbytes, clofset;
+	u_int32_t	mid = -1;
+	u_int32_t	magic, clbytes, clofset;
 
 	if (read(fd, (char *)&ex, sizeof(ex)) != sizeof(ex))
 		return(-1);
@@ -523,10 +522,9 @@ GetAOutFileInfo(fd, load, xfr, a_text, a_text_fill,
 		ex.a_drsize= mopFileGetBX((u_char *)&ex_swap, 28, 4);
 		break;
 	default:
-/*###525 [cc] syntax error before `}'%%%*/
+		break;
 	}
 
-#ifdef INFO
 	printf("a.out image (");
 	switch (N_GETMID (ex)) {
 	case MID_I386:
@@ -576,6 +574,7 @@ GetAOutFileInfo(fd, load, xfr, a_text, a_text_fill,
 		break;
 #endif
 	default:
+		break;
 	}
 	printf(") Magic: ");
 	switch (N_GETMAGIC (ex)) {
@@ -592,37 +591,33 @@ GetAOutFileInfo(fd, load, xfr, a_text, a_text_fill,
 		printf("QMAGIC");
 		break;
 	default:
-		printf("Unknown %d",N_GETMAGIC (ex));
+		printf("Unknown %ld", (long) N_GETMAGIC (ex));
 	}
 	printf("\n");
-	printf("Size of text:       %08x\n",ex.a_text);
-	printf("Size of data:       %08x\n",ex.a_data);
-	printf("Size of bss:        %08x\n",ex.a_bss);
-	printf("Size of symbol tab: %08x\n",ex.a_syms);
-	printf("Transfer Address:   %08x\n",ex.a_entry);
-	printf("Size of reloc text: %08x\n",ex.a_trsize);
-	printf("Size of reloc data: %08x\n",ex.a_drsize);
-#endif
+	printf("Size of text:       %08lx\n", (long)ex.a_text);
+	printf("Size of data:       %08lx\n", (long)ex.a_data);
+	printf("Size of bss:        %08lx\n", (long)ex.a_bss);
+	printf("Size of symbol tab: %08lx\n", (long)ex.a_syms);
+	printf("Transfer Address:   %08lx\n", (long)ex.a_entry);
+	printf("Size of reloc text: %08lx\n", (long)ex.a_trsize);
+	printf("Size of reloc data: %08lx\n", (long)ex.a_drsize);
+
 	magic = N_GETMAGIC (ex);
 	clbytes = getCLBYTES(mid);
 	clofset = clbytes - 1;
 
-/*###608 [cc] `load' undeclared (first use this function)%%%*/
 	if (load != NULL) {
 		*load   = 0;
 	}
 
-/*###612 [cc] `xfr' undeclared (first use this function)%%%*/
 	if (xfr != NULL) {
 		*xfr    = ex.a_entry;
 	}
 
-/*###616 [cc] `a_text' undeclared (first use this function)%%%*/
 	if (a_text != NULL) {
 		*a_text = ex.a_text;
 	}
 
-/*###620 [cc] `a_text_fill' undeclared (first use this function)%%%*/
 	if (a_text_fill != NULL) {
 		if (magic == ZMAGIC || magic == NMAGIC) {
 			*a_text_fill = clbytes - (ex.a_text & clofset);
@@ -634,12 +629,10 @@ GetAOutFileInfo(fd, load, xfr, a_text, a_text_fill,
 	        }
 	}
 
-/*###631 [cc] `a_data' undeclared (first use this function)%%%*/
 	if (a_data != NULL) {
 		*a_data = ex.a_data;
 	}
 
-/*###635 [cc] `a_data_fill' undeclared (first use this function)%%%*/
 	if (a_data_fill != NULL) {
 		if (magic == ZMAGIC || magic == NMAGIC) {
 			*a_data_fill = clbytes - (ex.a_data & clofset);
@@ -651,12 +644,10 @@ GetAOutFileInfo(fd, load, xfr, a_text, a_text_fill,
 	        }
 	}
 
-/*###646 [cc] `a_bss' undeclared (first use this function)%%%*/
 	if (a_bss != NULL) {
 		*a_bss  = ex.a_bss;
 	}
 
-/*###650 [cc] `a_bss_fill' undeclared (first use this function)%%%*/
 	if (a_bss_fill != NULL) {
 		if (magic == ZMAGIC || magic == NMAGIC) {
 			*a_bss_fill = clbytes - (ex.a_bss & clofset);
@@ -672,7 +663,6 @@ GetAOutFileInfo(fd, load, xfr, a_text, a_text_fill,
 	        }
 	}
 
-/*###665 [cc] `aout' undeclared (first use this function)%%%*/
 	if (aout != NULL) {
 		*aout = mid;
 	}
@@ -681,13 +671,12 @@ GetAOutFileInfo(fd, load, xfr, a_text, a_text_fill,
 #endif NOAOUT
 }
 
-/*###673 [cc] syntax error before `int'%%%*/
 int
 GetFileInfo(fd, load, xfr, aout,
 	    a_text, a_text_fill, a_data, a_data_fill, a_bss, a_bss_fill)
 	int	fd, *aout;
-	u_long	*load, *xfr, *a_text, *a_text_fill;
-	u_long	*a_data, *a_data_fill, *a_bss, *a_bss_fill;
+	u_int32_t	*load, *xfr, *a_text, *a_text_fill;
+	u_int32_t	*a_data, *a_data_fill, *a_bss, *a_bss_fill;
 {
 	int	err;
 
@@ -720,18 +709,15 @@ GetFileInfo(fd, load, xfr, aout,
 }
 
 ssize_t
-/*###711 [cc] syntax error before `mopFileRead'%%%*/
 mopFileRead(dlslot, buf)
 	struct dllist *dlslot;
 	u_char	*buf;
 {
 	ssize_t len, outlen;
 	int	bsz;
-	long	pos, notdone, total;
+	int32_t	pos, notdone, total;
 
-/*###719 [cc] `dlslot' undeclared (first use this function)%%%*/
 	if (dlslot->aout == -1) {
-/*###720 [cc] `buf' undeclared (first use this function)%%%*/
 		len = read(dlslot->ldfd,buf,dlslot->dl_bsz);
 	} else {
 		bsz = dlslot->dl_bsz;
@@ -743,10 +729,8 @@ mopFileRead(dlslot, buf)
 		if (pos < total) {
 			notdone = total - pos;
 			if (notdone <= bsz) {
-/*###731 [cc] subscripted value is neither array nor pointer%%%*/
 				outlen = read(dlslot->ldfd,&buf[len],notdone);
 			} else {
-/*###733 [cc] subscripted value is neither array nor pointer%%%*/
 				outlen = read(dlslot->ldfd,&buf[len],bsz);
 			}
 			len = len + outlen;
@@ -763,8 +747,7 @@ mopFileRead(dlslot, buf)
 			} else {
 				outlen = bsz;
 			}
-/*###749 [cc] subscripted value is neither array nor pointer%%%*/
-			bzero(&buf[len],outlen);
+			memset(&buf[len], 0, outlen);
 			len = len + outlen;
 			pos = pos + outlen;
 			bsz = bsz - outlen;
@@ -775,10 +758,8 @@ mopFileRead(dlslot, buf)
 		if ((bsz > 0) && (pos < total)) {
 			notdone = total - pos;
 			if (notdone <= bsz) {
-/*###760 [cc] subscripted value is neither array nor pointer%%%*/
 				outlen = read(dlslot->ldfd,&buf[len],notdone);
 			} else {
-/*###762 [cc] subscripted value is neither array nor pointer%%%*/
 				outlen = read(dlslot->ldfd,&buf[len],bsz);
 			}
 			len = len + outlen;
@@ -795,8 +776,7 @@ mopFileRead(dlslot, buf)
 			} else {
 				outlen = bsz;
 			}
-/*###778 [cc] subscripted value is neither array nor pointer%%%*/
-			bzero(&buf[len],outlen);
+			memset(&buf[len], 0, outlen);
 			len = len + outlen;
 			pos = pos + outlen;
 			bsz = bsz - outlen;
@@ -811,8 +791,7 @@ mopFileRead(dlslot, buf)
 			} else {
 				outlen = bsz;
 			}
-/*###793 [cc] subscripted value is neither array nor pointer%%%*/
-			bzero(&buf[len],outlen);
+			memset(&buf[len], 0, outlen);
 			len = len + outlen;
 			pos = pos + outlen;
 			bsz = bsz - outlen;
@@ -827,8 +806,7 @@ mopFileRead(dlslot, buf)
 			} else {
 				outlen = bsz;
 			}
-/*###808 [cc] subscripted value is neither array nor pointer%%%*/
-			bzero(&buf[len],outlen);
+			memset(&buf[len], 0, outlen);
 			len = len + outlen;
 			pos = pos + outlen;
 			bsz = bsz - outlen;
@@ -840,4 +818,3 @@ mopFileRead(dlslot, buf)
 
 	return(len);
 }
-/*###820 [cc] syntax error at end of input%%%*/
